@@ -37,8 +37,8 @@ int main(int argc, char **argv)
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
     QApplication app(argc, argv);
-    app.setOrganizationName(QStringLiteral("KDAB"));
-    app.setApplicationName(QStringLiteral("Test app"));
+    QCoreApplication::setOrganizationName(QStringLiteral("KDAB"));
+    QCoreApplication::setApplicationName(QStringLiteral("Test app"));
 
     KDDockWidgets::initFrontend(KDDockWidgets::FrontendType::QtWidgets);
 
@@ -205,6 +205,13 @@ int main(int argc, char **argv)
                                     "The main window will have a non-detachable central widget"));
     parser.addOption(centralWidget);
 
+    QCommandLineOption centralWidgetAllExtraSize(
+        "central-widget-all-extra-size",
+        QCoreApplication::translate("main",
+                                    "The main window will have a non-detachable central widget which "
+                                    "gets all the extra space when the window is enlarged (imples --central-widget"));
+    parser.addOption(centralWidgetAllExtraSize);
+
     QCommandLineOption tabsAtBottom("tabs-at-bottom", QCoreApplication::translate("main", "Shows tabs at bottom"));
     parser.addOption(tabsAtBottom);
 
@@ -276,6 +283,11 @@ int main(int argc, char **argv)
     if (parser.isSet(centralWidget))
         options |= MainWindowOption_HasCentralWidget;
 
+    if (parser.isSet(centralWidgetAllExtraSize)) {
+        options |= MainWindowOption_HasCentralWidget;
+        options |= MainWindowOption_CentralWidgetGetsAllExtraSpace;
+    }
+
     if (parser.isSet(noQtTool))
         internalFlags |= KDDockWidgets::Config::InternalFlag_DontUseQtToolWindowsForFloatingWindows;
 
